!--------------------------------------------------------------------
! DESCRPTION:
!	program to compute a mask of ones and zeros. All values in the
!	sep input file less than a given amount are set to a user-defined
!	"one". All values greater than the given amount are set to a
!	used defined "zero".
!--------------------------------------------------------------------	
!	Input:
!		min_amp: the given threshold value. <= go to "one" > go to "zero"
!		one: what to use for 1
!		zero: what to use for 0
!		verb : =1 for verbose output
!
!	EXAMPLES:
!		Myclip.x < junk.H min_amp=0.1 one=1 zero=0. > mask_ones_zeros.H
!---------------------------------------------------------------------
program Myclip

	use sep
	use mask_mod

	implicit none

	!! subroutine arguments
	integer							:: verb
	real							:: min_amp
	real							:: one
	real							:: zero

	!! internal variables
	real,allocatable,dimension(:) 	:: trace
	real,allocatable,dimension(:) 	:: o,d
	integer,allocatable,dimension(:):: n
	real							:: esize
	integer							:: i3,i2,n3,n2,n1,ndim
	
	!! initialize SEP stuff
	call sep_init(SOURCE)
	ndim=sep_dimension()
	if (ndim>3) then
		call seperr("ERROR: can only handle datasets up to 3 dimensions")
	end if
	allocate(n(ndim),o(ndim),d(ndim))

	!! read from history file
    call from_history("n",n)
    call from_history("o",o)
    call from_history("d",d)
    call from_history("esize",esize)

	!! copy to history file
    call to_history("n",n)
    call to_history("o",o)
    call to_history("d",d)
    call to_history("esize",esize)

	!! read from params
	call from_param('min_amp',min_amp)
	call from_param('one',one,1.0)
	call from_param('zero',zero,0.0)

	! allocate workspace
	allocate(trace(n(1)))

	if (ndim==3) then
		n3=n(3)
	else if (ndim==2) then
		n3=1
	end if
	n2=n(2)
	n1=n(1)

	do i3=1,n3
		do i2=1,n2

			!! read trace
			call sreed("in",trace,4*n1)

			!! call the subroutine that creates the mask
			call mask_it(trace,n1,min_amp,one,zero)

			!! output the masked trace
			call srite("out",trace,4*n1)
		end do
	end do

	!! deallocate work space
	deallocate(trace)

end program Myclip
